# othello
An othello game engine

## Dev environment
For the dev environment I recommend using [pyenv](https://github.com/pyenv/pyenv#installation) and [poetry](https://poetry.eustace.io/docs/#installation)
1. Download and install 
1. Run `poetry install` 
1. Run `poetry run python -m othello`